#!/perl/bin/perl 
use vars qw(%index $key $keys %matches @matches $word);
use strict;
use Win32::OLE;
use DB_File;
use Fcntl;
my $startdir="c:\\perl\\indexer\\";
	chdir $startdir or die "$startdir not found";

my ($database)=shift(@ARGV) or somehelp();
my @args=@ARGV;
{
	no strict;
if (not tie(%index,DB_File,"$database.db",O_RDONLY, 0, $DB_BTREE))  {
	print "Bad database name $database.db\n";
	my @l=glob "*.db";
	foreach (@l) { print $_,"\n" }
	somehelp();
}
}

# Look up each word
foreach $word (@ARGV) { 
    $keys = $index{lc $word};
    foreach $key (unpack("n*",$keys))
       { $matches{$key}++; }
}

# Rank by total matches
@matches = sort 
   { $matches{$b} <=> $matches{$a} 
     || $a <=> $b }
   (keys %matches);

my $hits=scalar (keys %matches);
if (! $hits)  {
  print "no match\n";
  exit 1 
}

print "We have $hits hits\n";
my $outfile="hits.html";
open OUT, ">$outfile" or die "can't open the html file to write";

my ($href, $name);
foreach $key (@matches) {
	$href = $index{pack("xn",$key)};
	header($href) if not $name;					#first time 
	$name=$href;
	$name=~ s#.*/([^/]+)\.\w+#$1#o;				# strip to the filename
	next if $name=~ /perltoc/o;					# redundant stuff should get a list
	print OUT qq|<a href= "$href" TARGET="page">$name</a><br><br>\n|;
}
untie(%index);
print OUT "</BODY></HTML>\n";
close OUT;

my $IE = Win32::OLE->GetActiveObject('InternetExplorer.Application');
 if (!$IE) {
   print "Calling Explorer\n";
   $IE = Win32::OLE->new('InternetExplorer.Application') or die "fatal oops\n";
}
$IE->{Visible}=1;
$IE->Navigate($startdir . 'frame.html');


sub header  {
	my $s=shift;
my $header=<< "END"
<HTML><HEAD><BASE TARGET="page"><TITLE>Lookup Index</TITLE>
<LINK REL="STYLESHEET" HREF="\\perl\\html\\win32prk.css" TYPE="text/css">
</HEAD>
<BODY><center><H4>$hits hits</H4></center>
<script language="JavaScript">
	parent.page.location.href= "$s";
</script>

END
;
print OUT $header;
}

sub somehelp  {
	print "USAGE: Look.pl DatabaseName word[s]\n";
	exit 1;
}

__END__



=head1 Look

=head2 Description

	Look up some term(s) in a list of HTML pages.
	Displays in framed format similar to Activestate's
		(using their stylesheet ;-).
	uses and tested with Win32::OLE 
		AND Internet Explorer 5.0 ONLY
			(mozillas are outaluck)
		
	First argument is the name of the database.
	Following arguments are terms to look up.
	
	This works so nicely I'm discovering many odd files
	formerly tucked away obscure corners.
	Really needs a lot of things but works so nicely
	as-is I've declared it finished 

=head2 USAGE:
	Look.pl DatabaseName word[s]

=head2 Author: Rob White  yzorderex@yahoo.com

=cut